@@ -12,7 +12,7 @@ class DDLexer:
         self.current_char = ''
         self.current_pos = -1
         self.next_char()
-        self.variable_prefixes = ['user', 'conv', 'dialog']
+        self.variable_prefixes = ['user', 'conv', 'dialog', 'wf']
         self.system_variables = ['conv.__utterance__', 'conv.__user__']
 
     # processes the next character
